@@ -22,3 +22,5 @@ KAFKA_START_TOPIC_CREATE_AUTO = False
 BLOOMFILTER_BLOCK = 1
 BLOOMFILTER_SIZE = 31
 BLOOMFILTER_SEED = 6
+KAFKA_DEFAULTS_START_PARTITIONS = 1
+KAFKA_DEFAULTS_START_REPLICATION = 1
