@@ -58,7 +58,9 @@ class KafkaQueue(Base):
     def pop(self, timeout=0):
         """Pop a request"""
         request = self.consumer.poll(0)
+        print(self.consumer)
         if len(self.consumer.assignment()) > 0:
+            print(self.consumer.assignment())
             if len(self.consumer.assignment()) == 1:
                 self.partition = self.consumer.assignment()[0].partition
             else:
