@@ -65,9 +65,9 @@ class Scheduler(object):
     def from_crawler(cls, crawler):
         instance = cls.from_settings(crawler.settings)
         instance.stats = crawler.stats
-        idle_number = crawler.settings.getint('IDLE_NUMBER', 360)
-        ext = cls(idle_number, crawler)
-        crawler.signals.connect(ext.spider_idle, signal=signals.spider_idle)
+        # idle_number = crawler.settings.getint('IDLE_NUMBER', 360)
+        # ext = cls(idle_number, crawler)
+        # crawler.signals.connect(ext.spider_idle, signal=signals.spider_idle)
         return instance
 
     def open(self, spider):
@@ -82,7 +82,7 @@ class Scheduler(object):
                                                                         defaults.KAFKA_DEFAULTS_PARTITIONS),
                                            replication_factor=self.settings.get('KAFKA_DEFAULTS_REPLICATION',
                                                                                 defaults.KAFKA_DEFAULTS_REPLICATION))
-        self.consumer = connection.create_consumer(self.spider.name,
+        self.consumer = connection.create_consumer(self.settings.get('GROUP_ID', self.spider.name),
                                                    bootstrap_servers=self.settings.get('KAFKA_DEFAULTS_HOST',
                                                                                        defaults.KAFKA_DEFAULTS_HOST))
         self.producer = connection.create_producer(bootstrap_servers=self.settings.get('KAFKA_DEFAULTS_HOST',
@@ -101,7 +101,7 @@ class Scheduler(object):
                 producer=self.producer,
                 consumer=self.consumer,
                 spider=spider,
-                topic=[self.topic.format(self.spider.name)],
+                topic=[self.settings.get('SPIDER_TOPIC' ,self.topic.format(self.spider.name))],
                 serializer=self.serializer,
             )
         except TypeError as e:
